AWS Syncr
=========

A python application that reads YAML and syncs definitions with amazon.

Tests
-----

Run the following::

	$ pip install -e .
	$ pip install -e ".[tests]"
	$ ./test.sh

Or use tox::

	$ tox

